const berndese = new Berndese();

// Translate from one textarea to another
function translate(fromLang, toLang) {
    document.getElementById(toLang).value = berndese.translate(
        fromLang, document.getElementById(fromLang).value
    );
}

// Translate handlers
Array.prototype.forEach.call(document.querySelectorAll('.translate'), (btn) => {
    btn.addEventListener('click', (e) => {
        e.preventDefault()
        translate(btn.dataset.fromlang, btn.dataset.tolang);
    });
});

// Clear buttons
function clearTextareas(...langs) {
    for (lang of langs) {
        document.getElementById(lang).value = '';
    };
}

Array.prototype.forEach.call(document.querySelectorAll('.clear'), (btn) => {
    btn.addEventListener('click', (e) => {
        e.preventDefault();
        clearTextareas(btn.dataset.lang);
    });
});

document.getElementById('clear-both').addEventListener('click', (e) => {
    e.preventDefault();
    clearTextareas(...berndese.languages);
});


// Pressing ctrl+enter translates to another language

// Save/Load hotkey checkbox value
if (typeof window.localStorage !== 'undefined') {
    try {
        const hotkey = document.getElementById('hotkey');
        // Load saved value
        hotkey.checked = (window.localStorage.getItem('hotkey') === 'true');
        // Add settings save handler
        hotkey.addEventListener('change', (e) => {
            window.localStorage.setItem(
                'hotkey', hotkey.checked ? 'true': 'false'
            );
        });        
    } catch(e) {
        console.log("localStorage isn't available")
    }
}

// Keypress handler
Array.prototype.forEach.call(
    document.querySelectorAll('.translate-area'), (el) => {
        el.addEventListener('keypress', function (e) {
            const focused = document.activeElement;
            if (!focused || !focused.classList.contains('translate-area'))
                return;
            if (!document.getElementById('hotkey').checked)
                return;

            if ((e.keyCode == 10 || e.keyCode == 13) && e.ctrlKey) {
                translate(
                    focused.dataset.fromlang,
                    focused.dataset.tolang
                );
            }
        });
    }
);

